==> plantuml-libs-7.1.0.tgz: package/distribution/fontawesome-6/Solid/UpRightAndDownLeftFromCenter.md <==
# UpRightAndDownLeftFromCenter


```text
fontawesome-6/Solid/UpRightAndDownLeftFromCenter
```

```text
include('fontawesome-6/Solid/UpRightAndDownLeftFromCenter')
```



| Illustration | UpRightAndDownLeftFromCenter |
| :---: | :---: |
| ![illustration for Illustration](../../fontawesome-6/Solid/UpRightAndDownLeftFromCenter.png) | ![illustration for UpRightAndDownLeftFromCenter](../../fontawesome-6/Solid/UpRightAndDownLeftFromCenter.Local.png) |




## UpRightAndDownLeftFromCenter

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element UpRightAndDownLeftFromCenter
include('fontawesome-6/Solid/UpRightAndDownLeftFromCenter')

' renders the element
UpRightAndDownLeftFromCenter('UpRightAndDownLeftFromCenter', 'Up Right And Down Left From Center', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element UpRightAndDownLeftFromCenter
include('fontawesome-6/Solid/UpRightAndDownLeftFromCenter')

' renders the element
UpRightAndDownLeftFromCenter('UpRightAndDownLeftFromCenter', 'Up Right And Down Left From Center', 'an optional tech label')
@enduml
```

==> plantuml-libs-9.1.0.tgz: package/distribution/fontawesome-6/Solid/UpRightAndDownLeftFromCenter.md <==
# UpRightAndDownLeftFromCenter


```text
fontawesome-6/Solid/UpRightAndDownLeftFromCenter
```

```text
include('fontawesome-6/Solid/UpRightAndDownLeftFromCenter')
```



| Illustration | UpRightAndDownLeftFromCenter |
| :---: | :---: |
| ![illustration for Illustration](../../fontawesome-6/Solid/UpRightAndDownLeftFromCenter.png) | ![illustration for UpRightAndDownLeftFromCenter](../../fontawesome-6/Solid/UpRightAndDownLeftFromCenter.Local.png) |




## UpRightAndDownLeftFromCenter

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element UpRightAndDownLeftFromCenter
include('fontawesome-6/Solid/UpRightAndDownLeftFromCenter')

' renders the element
UpRightAndDownLeftFromCenter('UpRightAndDownLeftFromCenter', 'Up Right And Down Left From Center', 'an optional tech label', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element UpRightAndDownLeftFromCenter
include('fontawesome-6/Solid/UpRightAndDownLeftFromCenter')

' renders the element
UpRightAndDownLeftFromCenter('UpRightAndDownLeftFromCenter', 'Up Right And Down Left From Center', 'an optional tech label', 'an optional description')
@enduml
```
